==> jc-1.4.0.tar.gz: gnu/java/awt/peer/gtk/GThreadNativeMethodRunner.h <==
// class gnu.java.awt.peer.gtk.GThreadNativeMethodRunner

// class file dependencies
// @dep_class 757748ed833a127a gnu_java_awt_peer_gtk_GThreadNativeMethodRunner
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a3a7cdc3e4c7ce28 java_lang_Thread

// header file dependencies
// @dep_header java_lang_Thread

#include "java/lang/Thread.h"

#ifndef _JC_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner_H_
#define _JC_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Thread$object;
struct _jc_java_util_Set$object;

// Typedefs
typedef struct _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$sub_refs	_jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$sub_refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$sub_nonrefs	_jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$sub_nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$refs	_jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$nonrefs	_jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$object	_jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$object;

typedef struct _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$fields_struct	_jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$fields_struct;
typedef const struct _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$vmethods	_jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$vmethods;
typedef const struct _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$vtable	_jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$vtable;
typedef const struct _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$vtype	_jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$vtype;

// Class fields structure
struct _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$fields_struct {
	struct _jc_object	*joinable;
	_jc_object_array	*threads;
};
extern _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$fields_struct _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$class_fields;

// Constructors
extern void _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$method$_init$cfce84ef4833cb37(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$object *, jlong, jlong, jboolean);

// Virtual methods
extern void _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$method$nativeRun$01194e21fbc44a8c(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$object *, jlong, jlong);
extern void _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$method$registerSelfJoinable$a111e515fb726394(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$object *);
extern void _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$method$run$8b940e4957c86ebf(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$method_info$nativeRun$01194e21fbc44a8c;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$method_info$registerSelfJoinable$a111e515fb726394;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$method_info$run$8b940e4957c86ebf;

// Static methods
extern void _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern void _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$method$deRegisterJoinable$d8b794b96f6ca798(_jc_env *, struct _jc_java_lang_Thread$object *);
extern jint _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$method$registerThread$a3da6bfc125b5983(_jc_env *, struct _jc_java_lang_Thread$object *);
extern struct _jc_java_lang_Thread$object *_jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$method$threadIDToThread$eb077a8b47fb9c42(_jc_env *, jint);
extern jint _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$method$threadToThreadID$c4c326a13f5c5903(_jc_env *, struct _jc_java_lang_Thread$object *);

// Virtual methods structure
struct _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$vmethods {
	void	(*nativeRun$01194e21fbc44a8c)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$object *, jlong, jlong);
	void	(*registerSelfJoinable$a111e515fb726394)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$object *);
	void	(*run$8b940e4957c86ebf)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$object *);
};

// Vtable
struct _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Thread$vmethods	java_lang_Thread;
	_jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$vmethods	gnu_java_awt_peer_gtk_GThreadNativeMethodRunner;
};

// Vtype
struct _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$refs {
    _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$sub_refs	gnu_java_awt_peer_gtk_GThreadNativeMethodRunner;
    _jc_java_lang_Thread$sub_refs	java_lang_Thread;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$sub_nonrefs {
	jlong	funcPtr;
	jlong	funcArg;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Thread$sub_nonrefs	java_lang_Thread;
    _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$sub_nonrefs	gnu_java_awt_peer_gtk_GThreadNativeMethodRunner;
};

// Object instance structure
struct _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$object {
	_jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$vtype	*vtype;
	_jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$vtype _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_peer_gtk_GThreadNativeMethodRunner, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$class_object;

#endif	/* _JC_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner_H_ */

==> jc-1.4.6.tar.gz: gnu/java/awt/peer/gtk/GThreadNativeMethodRunner.h <==
// class gnu.java.awt.peer.gtk.GThreadNativeMethodRunner

// class file dependencies
// @dep_class 757748ed833a127a gnu_java_awt_peer_gtk_GThreadNativeMethodRunner
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 7e33d4feabbc3f15 java_lang_Thread

// header file dependencies
// @dep_header java_lang_Thread

#include "java/lang/Thread.h"

#ifndef _JC_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner_H_
#define _JC_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Thread$object;
struct _jc_java_util_Set$object;

// Typedefs
typedef struct _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$sub_refs	_jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$sub_refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$sub_nonrefs	_jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$sub_nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$refs	_jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$nonrefs	_jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$object	_jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$object;

typedef struct _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$fields_struct	_jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$fields_struct;
typedef const struct _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$vmethods	_jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$vmethods;
typedef const struct _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$vtable	_jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$vtable;
typedef const struct _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$vtype	_jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$vtype;

// Class fields structure
struct _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$fields_struct {
	struct _jc_object	*joinable;
	_jc_object_array	*threads;
};
extern _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$fields_struct _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$class_fields;

// Constructors
extern void _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$method$_init$cfce84ef4833cb37(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$object *, jlong, jlong, jboolean) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$method$nativeRun$01194e21fbc44a8c(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$object *, jlong, jlong) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$method$registerSelfJoinable$a111e515fb726394(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$method$run$8b940e4957c86ebf(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$method_info$nativeRun$01194e21fbc44a8c;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$method_info$registerSelfJoinable$a111e515fb726394;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$method_info$run$8b940e4957c86ebf;

// Static methods
extern void _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$method$deRegisterJoinable$d8b794b96f6ca798(_jc_env *, struct _jc_java_lang_Thread$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$method$registerThread$a3da6bfc125b5983(_jc_env *, struct _jc_java_lang_Thread$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Thread$object *_jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$method$threadIDToThread$eb077a8b47fb9c42(_jc_env *, jint) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$method$threadToThreadID$c4c326a13f5c5903(_jc_env *, struct _jc_java_lang_Thread$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$vmethods {
	void	(*nativeRun$01194e21fbc44a8c)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$object *, jlong, jlong) _JC_JCNI_ATTR;
	void	(*registerSelfJoinable$a111e515fb726394)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$object *) _JC_JCNI_ATTR;
	void	(*run$8b940e4957c86ebf)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Thread$vmethods	java_lang_Thread;
	_jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$vmethods	gnu_java_awt_peer_gtk_GThreadNativeMethodRunner;
};

// Vtype
struct _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$refs {
    _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$sub_refs	gnu_java_awt_peer_gtk_GThreadNativeMethodRunner;
    _jc_java_lang_Thread$sub_refs	java_lang_Thread;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$sub_nonrefs {
	jlong	funcPtr;
	jlong	funcArg;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Thread$sub_nonrefs	java_lang_Thread;
    _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$sub_nonrefs	gnu_java_awt_peer_gtk_GThreadNativeMethodRunner;
};

// Object instance structure
struct _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$object {
	_jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$vtype	*vtype;
	_jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$vtype _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_peer_gtk_GThreadNativeMethodRunner, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner$class_object;

#endif	/* _JC_gnu_java_awt_peer_gtk_GThreadNativeMethodRunner_H_ */
